import { useState } from 'react'
import { Button, Checkbox, Flex, Modal } from 'antd'
import type { CheckboxProps } from 'antd'
import { useNavigate } from 'react-router'
import AppSteps from '@/components/AppSteps'

const CheckboxGroup = Checkbox.Group

const plainOptions = ['会员情况', '客户满意度', '出生日期', '访问页面时长', '交易状态', '商品状态', '快递反馈']
const defaultCheckedList = ['会员情况', '客户满意度']

export default function ButtonModal() {
  const navigate = useNavigate()

  const [open, setOpen] = useState(false)
  const [current, setCurrent] = useState(0)

  const [checkedList, setCheckedList] = useState<string[]>(defaultCheckedList)

  const checkAll = plainOptions.length === checkedList.length
  const indeterminate = checkedList.length > 0 && checkedList.length < plainOptions.length

  const onChange = (list: string[]) => {
    setCheckedList(list)
  }

  const onCheckAllChange: CheckboxProps['onChange'] = (e) => {
    setCheckedList(e.target.checked ? plainOptions : [])
  }

  const next = () => {
    setCurrent(current + 1)
  }

  const prev = () => {
    setCurrent(current - 1)
  }

  const steps = [
    {
      title: '探索缺失值字段',
      content: (
        <>
          <Flex justify="space-between" style={{ marginBottom: 20 }}>
            探索结果：
            <Checkbox indeterminate={indeterminate} onChange={onCheckAllChange} checked={checkAll}>
              全选
            </Checkbox>
          </Flex>
          <CheckboxGroup options={plainOptions} value={checkedList} onChange={onChange} />
        </>
      ),
    },
    {
      title: '探索字段缺失值',
      content: (
        <>
          <Flex justify="space-between" style={{ marginBottom: 20 }}>
            探索结果：
          </Flex>
          <p>字段1：该字段有缺失值的数据有：A000001、A000002...</p>
          <p>字段1：该字段有缺失值的数据有：A000001、A000002...</p>
          <p>字段1：该字段有缺失值的数据有：A000001、A000002...</p>
          <p>字段1：该字段有缺失值的数据有：A000001、A000002...</p>
          <p>字段1：该字段有缺失值的数据有：A000001、A000002...</p>
        </>
      ),
    },
    {
      title: '填充字段缺失值',
      content: (
        <>
          <Flex justify="space-between" style={{ marginBottom: 20 }}>
            请选择需要填充的字段：
            <Checkbox indeterminate={indeterminate} onChange={onCheckAllChange} checked={checkAll}>
              全选
            </Checkbox>
          </Flex>
          <CheckboxGroup options={plainOptions} value={checkedList} onChange={onChange} />
        </>
      ),
    },
  ]

  return (
    <>
      <Button type="primary" onClick={() => setOpen(true)}>
        缺失值
      </Button>
      <Modal
        title="缺失值探索"
        open={open}
        footer={
          <Flex justify="center" gap={20}>
            {current === 0 && <Button type="primary">智能探索缺失值字段</Button>}
            {current === 0 && (
              <Button type="primary" disabled={!checkedList.length} onClick={() => next()}>
                进一步探索字段缺失值情况
              </Button>
            )}

            {current > 0 && <Button onClick={() => prev()}>上一步</Button>}
            {current > 0 && current < steps.length - 1 && (
              <Button type="primary" onClick={() => next()}>
                下一步
              </Button>
            )}
            {current === steps.length - 1 && (
              <Button type="primary" onClick={() => navigate('/data/preprocess/null')}>
                跳转数据预处理
              </Button>
            )}
          </Flex>
        }
        destroyOnClose
        width={800}
        onCancel={() => setOpen(false)}>
        <div style={{ minHeight: 300, padding: '40px 0' }}>
          <AppSteps current={current} items={steps} style={{ marginBottom: 40 }} />
          <div>{steps[current].content}</div>
        </div>
      </Modal>
    </>
  )
}
